@@ -1,5 +1,3 @@
-use std::sync::Arc;
-
 use libloading::Library;
 use once_cell::sync::OnceCell;
 use tanoshi_lib::prelude::Extension;
@@ -7,13 +5,17 @@ use tanoshi_lib::prelude::Extension;
 pub struct Source {
     pub(crate) extension: OnceCell<Box<dyn Extension>>,
     #[allow(dead_code)]
-    pub(crate) lib: Option<Arc<Library>>,
+    pub(crate) lib: Option<Library>,
+    pub rustc_version: String,
+    pub lib_version: String,
 }
 
 impl Source {
-    pub fn new(lib: Arc<Library>) -> Source {
+    pub fn new(lib: Library, rustc_version: &str, lib_version: &str) -> Source {
         Source {
             lib: Some(lib),
+            rustc_version: rustc_version.to_string(),
+            lib_version: lib_version.to_string(),
             extension: OnceCell::new(),
         }
     }
@@ -21,6 +23,8 @@ impl Source {
     pub fn from(extension: Box<dyn Extension>) -> Self {
         Self {
             lib: None,
+            rustc_version: tanoshi_lib::RUSTC_VERSION.to_string(),
+            lib_version: tanoshi_lib::LIB_VERSION.to_string(),
             extension: OnceCell::from(extension),
         }
     }
